==> remote-log-1.0.6.tar.gz: remote-log-1.0.6/remote_log/remote_log.py <==
import requests
import os
import json
import threading
from .sysinfo import get_system_info

# Base directory for the library
BASE_DIR = os.path.dirname(os.path.abspath(__file__))
OFFLINE_LOGS_DIR = os.path.join(BASE_DIR, "offline_logs")

# Ensure the offline_logs directory exists
if not os.path.exists(OFFLINE_LOGS_DIR):
    os.makedirs(OFFLINE_LOGS_DIR)

def get_offline_storage_path(url):
    # Convert the URL to a filename-friendly string
    filename = ''.join(e for e in url if e.isalnum())
    return os.path.join(OFFLINE_LOGS_DIR, f"{filename}_offline_payloads.json")

def send_data(url, payload, offline_storage_path):
    # Try to send the payload
    try:
        response = requests.post(url, json=payload)
        response.raise_for_status()  # Raise an exception for HTTP errors
        
        # Clear the offline storage file after sending
        if os.path.exists(offline_storage_path):
            os.remove(offline_storage_path)
    
    except requests.RequestException:
        # If the request fails, store the current payload for later
        new_payload = {
            "command": payload["data"][0]["command"],
            "system": get_system_info()
        }
        
        if os.path.exists(offline_storage_path):
            with open(offline_storage_path, 'r') as file:
                offline_payloads = json.load(file)
            # Insert the new payload at the beginning (stack-like order)
            offline_payloads.insert(0, new_payload)
        else:
            offline_payloads = [new_payload]
        
        with open(offline_storage_path, 'w') as file:
            json.dump(offline_payloads, file)

def remote_log(url, command):
    # Define the payload for the POST request
    payload = {
        "data": [
            {
                "command": command,
                "system": get_system_info()
            }
        ]
    }
    
    # Get the offline storage path for the given URL
    offline_storage_path = get_offline_storage_path(url)
    
    # Check for previously stored payloads and add them to the data
    if os.path.exists(offline_storage_path):
        with open(offline_storage_path, 'r') as file:
            offline_payloads = json.load(file)
        payload["data"].extend(offline_payloads)
    
    # Use threading to send data in the background
    thread = threading.Thread(target=send_data, args=(url, payload, offline_storage_path))
    thread.start()

# Example usage:
# url = "http://example.com/api"
# command = "some_command"
# remote_log(url, command)

==> remote-log-1.0.8.tar.gz: remote-log-1.0.8/remote_log/remote_log.py <==
import requests
import os
import json
import multiprocessing
from .sysinfo import get_system_info

# Base directory for the library
BASE_DIR = os.path.dirname(os.path.abspath(__file__))
OFFLINE_LOGS_DIR = os.path.join(BASE_DIR, "offline_logs")

# Ensure the offline_logs directory exists
if not os.path.exists(OFFLINE_LOGS_DIR):
    os.makedirs(OFFLINE_LOGS_DIR)

def get_offline_storage_path(url):
    # Convert the URL to a filename-friendly string
    filename = ''.join(e for e in url if e.isalnum())
    return os.path.join(OFFLINE_LOGS_DIR, f"{filename}_offline_payloads.json")

def send_data(url, payload, offline_storage_path):
    # Try to send the payload
    try:
        response = requests.post(url, json=payload)
        response.raise_for_status()  # Raise an exception for HTTP errors
        
        # Clear the offline storage file after sending
        if os.path.exists(offline_storage_path):
            os.remove(offline_storage_path)
    
    except requests.RequestException:
        # If the request fails, store the current payload for later
        new_payload = {
            "command": payload["data"][0]["command"],
            "system": get_system_info()
        }
        
        if os.path.exists(offline_storage_path):
            with open(offline_storage_path, 'r') as file:
                offline_payloads = json.load(file)
            # Insert the new payload at the beginning (stack-like order)
            offline_payloads.insert(0, new_payload)
        else:
            offline_payloads = [new_payload]
        
        with open(offline_storage_path, 'w') as file:
            json.dump(offline_payloads, file)

def remote_log(url, command):
    # Define the payload for the POST request
    payload = {
        "data": [
            {
                "command": command,
                "system": get_system_info()
            }
        ]
    }
    
    # Get the offline storage path for the given URL
    offline_storage_path = get_offline_storage_path(url)
    
    # Check for previously stored payloads and add them to the data
    if os.path.exists(offline_storage_path):
        with open(offline_storage_path, 'r') as file:
            offline_payloads = json.load(file)
        payload["data"].extend(offline_payloads)
    
    # Use multiprocessing to send data in a separate process
    process = multiprocessing.Process(target=send_data, args=(url, payload, offline_storage_path))
    process.start()
    # The function will return immediately, while send_data runs in its own process.

# Example usage:
# url = "http://example.com/api"
# command = "some_command"
# remote_log(url, command)
